@@ -1,13 +1,6 @@
 package JE::Object::String;
 
-
-=begin stuff for MakeMaker
-
-use JE; our $VERSION = $JE::VERSION;
-
-=end
-
-=cut
+our $VERSION = '0.002';
 
 
 use strict;
@@ -20,15 +13,20 @@ require JE::Object::Function;
 require JE::String;
 
 
+# ~~~ write 'new_constructor' if necessary
+#our $constructor = __PACKAGE__->make_constructor;
+#our $prototype   = prop $constructor 'prototype';
+#for($prototype) {
+#	# ~~~ I need to finish adding all the usual string methods
+#	prop $_ toString => new_method JE::Object::Function sub {
+#		bless {%{+shift}}, 'JE::String';
+#	};
+#}
+
+
+# ~~~ make certain methods/props get delegated to JE::String via
+#     $$$self{value}->prop
 
-our $constructor = __PACKAGE__->make_constructor;
-our $prototype   = prop $constructor 'prototype';
-for($prototype) {
-	# ~~~ I need to finish adding all the usual string methods
-	prop $_ toString => new_method JE::Object::Function sub {
-		bless {%{+shift}}, 'JE::String';
-	};
-}
 
 =head1 NAME
 
@@ -38,11 +36,9 @@ JE::Object::String - JavaScript String object class
 
   use JE::Object::String;
 
-  $js_str = new JE::Object::String "etetfyoyfoht";
+  $js_str_obj = new JE::Object::String $scope, "etetfyoyfoht";
 
-  $perl_str = $js_str->value;
-
-  $js_str->id; # returns a number uniquely identifying the object
+  $perl_str = $js_str_obj->value;
 
 =head1 DESCRIPTION
 
@@ -53,9 +49,9 @@ I<primitive> string value, while this module implements the I<objects.>
 =cut
 
 sub new {
-	my($class, $val) = (shift,shift);
-	my $self = bless JE::Object->new, $class;
-	$$self{value} = new JE::String $val;
+	my($class, $scope, $val) = @_;
+	my $self = bless JE::Object->new($scope), $class;
+	$$$self{value} = new JE::String $val;
 	$self;
 }
 
@@ -71,16 +67,14 @@ sub def_value { shift->method('toString') } # ~~~ make sure this is
 
 return "a true value";
 
-=head1 AUTHOR
-
-Father Chrysostomos <sprout [at] cpan [dot] org>
-
 =head1 SEE ALSO
 
 =over 4
 
 =item JE
+
 =item JE::Object
+
 =item JE::String
 
 =cut
